@@ -91,6 +91,7 @@ class AxesCacheHandler(AbstractAxesHandler, AxesBaseHandler):
             request.axes_ip_address,
             request.axes_user_agent,
             request.axes_path_info,
+            request,
         )
 
         if self.is_whitelisted(request, credentials):
@@ -98,6 +99,7 @@ class AxesCacheHandler(AbstractAxesHandler, AxesBaseHandler):
             return
 
         failures_since_start = 1 + self.get_failures(request, credentials)
+        request.axes_failures_since_start = failures_since_start
 
         if failures_since_start > 1:
             log.warning(
@@ -147,6 +149,7 @@ class AxesCacheHandler(AbstractAxesHandler, AxesBaseHandler):
             request.axes_ip_address,
             request.axes_user_agent,
             request.axes_path_info,
+            request,
         )
 
         log.info("AXES: Successful login by %s.", client_str)
@@ -169,6 +172,7 @@ class AxesCacheHandler(AbstractAxesHandler, AxesBaseHandler):
             request.axes_ip_address,
             request.axes_user_agent,
             request.axes_path_info,
+            request,
         )
 
         log.info("AXES: Successful logout by %s.", client_str)
