@@ -241,7 +241,11 @@ def get_client_cache_key(
 
 
 def get_client_str(
-    username: str, ip_address: str, user_agent: str, path_info: str
+    username: str,
+    ip_address: str,
+    user_agent: str,
+    path_info: str,
+    request: HttpRequest,
 ) -> str:
     """
     Get a readable string that can be used in e.g. logging to distinguish client requests.
@@ -255,11 +259,11 @@ def get_client_str(
 
         if callable(settings.AXES_CLIENT_STR_CALLABLE):
             return settings.AXES_CLIENT_STR_CALLABLE(
-                username, ip_address, user_agent, path_info
+                username, ip_address, user_agent, path_info, request
             )
         if isinstance(settings.AXES_CLIENT_STR_CALLABLE, str):
             return import_string(settings.AXES_CLIENT_STR_CALLABLE)(
-                username, ip_address, user_agent, path_info
+                username, ip_address, user_agent, path_info, request
             )
         raise TypeError(
             "settings.AXES_CLIENT_STR_CALLABLE needs to be a string, callable or None."
@@ -362,7 +366,7 @@ def get_lockout_response(request, credentials: dict = None) -> HttpResponse:
             "settings.AXES_LOCKOUT_CALLABLE needs to be a string, callable, or None."
         )
 
-    status = 403
+    status = settings.AXES_HTTP_RESPONSE_CODE
     context = {
         "failure_limit": get_failure_limit(request, credentials),
         "username": get_client_username(request, credentials) or "",
