@@ -1,5 +1,7 @@
 from typing import Callable
 
+from django.conf import settings
+
 from axes.helpers import get_lockout_response
 
 
@@ -8,6 +10,10 @@ class AxesMiddleware:
     Middleware that calculates necessary HTTP request attributes for attempt monitoring
     and maps lockout signals into readable HTTP 403 Forbidden responses.
 
+    If a project uses ``django rest framework`` then the middleware updates the
+    request and checks whether the limit has been exceeded. It's needed only
+    for integration with DRF because it uses its own request object.
+
     This middleware recognizes a logout monitoring flag in the request and
     and uses the ``axes.helpers.get_lockout_response`` handler for returning
     customizable and context aware lockout message to the end user if necessary.
@@ -29,7 +35,8 @@ class AxesMiddleware:
     def __call__(self, request):
         response = self.get_response(request)
 
-        if getattr(request, "axes_locked_out", None):
-            response = get_lockout_response(request)  # type: ignore
+        if settings.AXES_ENABLED:
+            if getattr(request, "axes_locked_out", None):
+                response = get_lockout_response(request)  # type: ignore
 
         return response
